@@ -42,10 +42,10 @@ class DashboardExtension(LavaServerExtension):
         menu = super(DashboardExtension, self).get_menu()
         subm = []
         menu.sub_menu = subm
-        subm.append(Menu("Image Reports", reverse("dashboard_app.views.images.image_report_list")))
-        subm.append(Menu("Image Reports 2.0", reverse("dashboard_app.views.image_reports.views.image_report_list")))
-        subm.append(Menu("Filters", reverse("dashboard_app.views.filters.views.filters_list")))
-        subm.append(Menu("Bundle Streams", reverse("dashboard_app.views.bundle_stream_list")))
+        subm.append(Menu("Image Reports", reverse("lava_dashboard_image_report_list")))
+        subm.append(Menu("Image Reports 2.0", reverse("lava_dashboard_image_report_report_list")))
+        subm.append(Menu("Filters", reverse("lava_dashboard_filters_list")))
+        subm.append(Menu("Bundle Streams", reverse("lava_dashboard_bundle_stream_list")))
 
         return menu
 
