@@ -24,7 +24,6 @@ from lava_results_app.models import (
     QueryCondition,
     TestCase,
     TestSuite,
-    TestSet,
 )
 
 from lava_scheduler_app.models import TestJob
@@ -34,6 +33,10 @@ from lava_scheduler_app.tables import (
     TagsColumn,
     RestrictedIDLinkColumn
 )
+from lava_results_app.tables import (
+    ResultsTable,
+    SuiteTable
+)
 
 
 class UserQueryTable(LavaTable):
@@ -54,8 +57,8 @@ class UserQueryTable(LavaTable):
         value = ' '.join(value.split(" ")[:15])
         return value.split("\n")[0]
 
-    user = tables.TemplateColumn('''
-    {{ record.user.username }}
+    owner = tables.TemplateColumn('''
+    {{ record.owner.username }}
     ''')
 
     query_group = tables.Column()
@@ -70,11 +73,15 @@ class UserQueryTable(LavaTable):
     ''')
     remove.orderable = False
 
+    last_updated = tables.TemplateColumn('''
+    {% if record.is_live %}{% now "DATETIME_FORMAT" %}_live{% elif not record.last_updated %}Never{% else %}{{ record.last_updated }}{% endif %}
+    ''')
+
     class Meta(LavaTable.Meta):
         model = Query
         fields = (
             'name', 'is_published', 'description',
-            'query_group', 'user', 'view', 'remove'
+            'query_group', 'owner', 'last_updated', 'view', 'remove'
         )
         sequence = fields
         searches = {
@@ -101,7 +108,7 @@ class OtherQueryTable(UserQueryTable):
 
     class Meta(UserQueryTable.Meta):
         fields = (
-            'name', 'description', 'user',
+            'name', 'description', 'owner',
         )
         sequence = fields
         exclude = (
@@ -128,7 +135,7 @@ class GroupQueryTable(UserQueryTable):
 
     class Meta(UserQueryTable.Meta):
         fields = (
-            'name', 'description', 'user',
+            'name', 'description', 'owner',
         )
         sequence = fields
 
@@ -156,7 +163,7 @@ class QueryTestJobTable(JobTable):
         queries = {}
 
 
-class QueryTestCaseTable(LavaTable):
+class QueryTestCaseTable(SuiteTable):
 
     name = tables.TemplateColumn('''
     <a href="{{ record.get_absolute_url }}">{{ record.name }}</a>
@@ -166,7 +173,7 @@ class QueryTestCaseTable(LavaTable):
         super(QueryTestCaseTable, self).__init__(data, *args, **kwargs)
         self.length = 25
 
-    class Meta:
+    class Meta(SuiteTable.Meta):
         model = TestCase
         attrs = {"class": "table table-hover", "id": "query-results-table"}
         per_page_field = "length"
@@ -175,7 +182,7 @@ class QueryTestCaseTable(LavaTable):
         ]
 
 
-class QueryTestSuiteTable(LavaTable):
+class QueryTestSuiteTable(ResultsTable):
 
     name = tables.TemplateColumn('''
     <a href="{{ record.get_absolute_url }}">{{ record.name }}</a>
@@ -185,23 +192,7 @@ class QueryTestSuiteTable(LavaTable):
         super(QueryTestSuiteTable, self).__init__(data, *args, **kwargs)
         self.length = 25
 
-    class Meta:
+    class Meta(ResultsTable.Meta):
         model = TestSuite
         attrs = {"class": "table table-hover", "id": "query-results-table"}
         per_page_field = "length"
-
-
-class QueryTestSetTable(LavaTable):
-
-    name = tables.TemplateColumn('''
-    <a href="{{ record.get_absolute_url }}">{{ record.name }}</a>
-    ''')
-
-    def __init__(self, data, *args, **kwargs):
-        super(QueryTestSetTable, self).__init__(data, *args, **kwargs)
-        self.length = 25
-
-    class Meta:
-        model = TestSet
-        attrs = {"class": "table table-hover", "id": "query-results-table"}
-        per_page_field = "length"
