@@ -26,11 +26,11 @@ from lava_scheduler_app.models import (
     TestJob,
     DevicesUnavailableException,
     DeviceDictionary,
-    SubmissionException,
     _check_exclusivity,
 )
 from lava_scheduler_daemon.dbjobsource import DatabaseJobSource
-from lava_scheduler_app.schema import validate_submission, validate_device
+from lava_scheduler_app.schema import validate_submission, validate_device, SubmissionException
+from lava_scheduler_app.dbutils import testjob_submission
 import simplejson
 
 logger = logging.getLogger()
@@ -928,6 +928,62 @@ actions:
         job = TestJob.objects.get(id=job_id)
         self.assertTrue(job.is_pipeline)
 
+    def test_health_determination(self):
+        user = self.factory.ensure_user('test', 'e@mail.invalid', 'test')
+        user.user_permissions.add(
+            Permission.objects.get(codename='add_testjob'))
+        user.save()
+        device_type = self.factory.make_device_type('beaglebone-black')
+        device = self.factory.make_device(device_type=device_type, hostname="black01")
+        device.save()
+        filename = os.path.join(os.path.dirname(__file__), 'master-check.json')
+        self.assertTrue(os.path.exists(filename))
+        with open(filename, 'r') as json_file:
+            definition = json_file.read()
+        # simulate UI submission
+        job = self.factory.make_testjob(definition=definition, submitter=user)
+        self.assertFalse(job.health_check)
+        job.save(update_fields=['health_check', 'requested_device'])
+        self.assertFalse(job.health_check)
+        job.delete()
+        # simulate API submission
+        job = testjob_submission(definition, user)
+        self.assertFalse(job.health_check)
+        self.assertIsNone(job.requested_device)
+        job.delete()
+        job = testjob_submission(definition, user, check_device=None)
+        self.assertFalse(job.health_check)
+        self.assertIsNone(job.requested_device)
+        job.delete()
+        # simulate initiating a health check
+        job = testjob_submission(definition, user, check_device=device)
+        self.assertTrue(job.health_check)
+        self.assertEqual(job.requested_device.hostname, device.hostname)
+        job.delete()
+        # modify definition to use the deprecated target support
+        device2 = self.factory.make_device(device_type=device_type, hostname="black02")
+        device2.save()
+        def_dict = json.loads(definition)
+        self.assertNotIn('target', def_dict)
+        def_dict['target'] = device2.hostname
+        definition = json.dumps(def_dict)
+        # simulate API submission with target set
+        job = testjob_submission(definition, user, check_device=None)
+        self.assertFalse(job.health_check)
+        self.assertEqual(job.requested_device.hostname, device2.hostname)
+        job.delete()
+        # healthcheck designation overrides target (although this is itself an admin error)
+        job = testjob_submission(definition, user, check_device=device)
+        self.assertTrue(job.health_check)
+        self.assertEqual(job.requested_device.hostname, device.hostname)
+        job.delete()
+        # check malformed JSON
+        self.assertRaises(SubmissionException, testjob_submission, definition[:100], user)
+        # check non-existent targets
+        def_dict['target'] = 'nosuchdevice'
+        definition = json.dumps(def_dict)
+        self.assertRaises(Device.DoesNotExist, testjob_submission, definition, user)
+
 
 class TransactionTestCaseWithFactory(TransactionTestCase):
 
@@ -1072,3 +1128,64 @@ job_name: qemu-pipeline
             self.assertIn('required key not provided', str(exc))
             self.assertIn('job', str(exc))
             self.assertIn('timeouts', str(exc))
+
+    def test_compression_change(self):
+
+        bad_submission = """
+job_name: bbb-ramdisk
+visibility: public
+timeouts:
+  job:
+    minutes: 15
+  action:
+    minutes: 5
+actions:
+    - deploy:
+        to: tftp
+        kernel:
+          url: http://test.com/foo
+        ramdisk:
+          url: http://test.com/bar
+          header: u-boot
+          add-header: u-boot
+          compression: gz
+        os: oe
+        # breakage at the dtb block of a tftp deploy
+        dtb:
+          location: http://test.com/baz
+                """
+        try:
+            validate_submission(yaml.load(bad_submission))
+        except SubmissionException as exc:
+            self.assertIn('required key not provided', str(exc))
+            self.assertIn('dtb', str(exc))
+            self.assertIn('url', str(exc))
+
+        bad_submission = """
+job_name: bbb-ramdisk
+visibility: public
+timeouts:
+  job:
+    minutes: 15
+  action:
+    minutes: 5
+actions:
+    - deploy:
+        to: tftp
+        kernel:
+          url: http://test.com/foo
+        ramdisk:
+          url: http://test.com/bar
+          header: u-boot
+          add-header: u-boot
+          compression: gz
+        os: oe
+        # breakage using the original syntax
+        dtb: http://test.com/baz
+                """
+        try:
+            validate_submission(yaml.load(bad_submission))
+        except SubmissionException as exc:
+            self.assertIn('expected a dictionary for dictionary value', str(exc))
+            self.assertIn('dtb', str(exc))
+            self.assertNotIn('url', str(exc))
