@@ -122,6 +122,8 @@ if AUTH_CROWD_SERVER_REST_URI:
     if distro_settings.get_setting("AUTH_CROWD_GROUP_MAP"):
         AUTH_CROWD_GROUP_MAP = distro_settings.get_setting("AUTH_CROWD_GROUP_MAP")
 
+AUTH_DEBIAN_SSO = distro_settings.get_setting("AUTH_DEBIAN_SSO")
+
 # LDAP authentication config
 AUTH_LDAP_SERVER_URI = distro_settings.get_setting("AUTH_LDAP_SERVER_URI")
 if AUTH_LDAP_SERVER_URI:
@@ -172,6 +174,9 @@ if AUTH_LDAP_SERVER_URI:
 
     # read any LDAP login message to use from the settings.conf
     LOGIN_MESSAGE_LDAP = distro_settings.get_setting("LOGIN_MESSAGE_LDAP", "")
+elif AUTH_DEBIAN_SSO:
+    MIDDLEWARE_CLASSES.append('lava_server.debian_sso.DebianSsoUserMiddleware')
+    AUTHENTICATION_BACKENDS += ('lava_server.debian_sso.DebianSsoUserBackend',)
 
 # read branding details
 BRANDING_ALT = distro_settings.get_setting("BRANDING_ALT", "Linaro logo")
@@ -180,6 +185,10 @@ BRANDING_URL = distro_settings.get_setting("BRANDING_URL", 'http://www.linaro.or
 BRANDING_HEIGHT = distro_settings.get_setting("BRANDING_HEIGHT", 22)
 BRANDING_WIDTH = distro_settings.get_setting("BRANDING_WIDTH", 22)
 
+HIDE_V1_DOCS = distro_settings.get_setting("HIDE_V1_DOCS", False)
+HIDE_V2_DOCS = distro_settings.get_setting("HIDE_V2_DOCS", False)
+CUSTOM_DOCS = distro_settings.get_setting("CUSTOM_DOCS", {})
+
 # Logging
 
 LOGGING = {
